@@ -156,7 +156,7 @@ pcheck.dsn <- function(dsn, dbconnopen=TRUE) {
 
 #' @rdname pcheck_desc
 #' @export
-pcheck.table <- function(tab=NULL, tab_dsn=NULL, tabnm=NULL, tabqry=NULL,
+pcheck.table <- function(tab=NULL, conn=NULL, tab_dsn=NULL, tabnm=NULL, tabqry=NULL,
 	caption=NULL, returnsf=TRUE, factors=FALSE, returnDT=TRUE, warn=NULL,
 	stopifnull=FALSE, stopifinvalid=FALSE, nullcheck=FALSE, obj=FALSE, gui=FALSE){
 
@@ -206,7 +206,25 @@ pcheck.table <- function(tab=NULL, tab_dsn=NULL, tabnm=NULL, tabqry=NULL,
   if (gui && !.Platform$OS.type=="windows") {
     stop("gui not supported")
   }
-  if (is.null(tab) && is.null(tab_dsn)) {
+  if (!is.null(conn)) {
+    if (!DBI::dbIsValid(conn)) {
+      warning("invalid database connection")
+      exit()
+    } else {
+      tablst <- DBI::dbListTables(conn)
+      if (is.character(tab) && length(tab) == 1) {
+        tab <- findnm(tab, tablst, returnNULL=TRUE)
+        if (is.null(tab) && stopifnull) {
+          warning("tab is NULL")
+          exit()
+        }
+        return(tab)
+      } else {
+        warning("invalid tab... must be character name in database")
+        exit()
+      }
+    }
+  } else if (is.null(tab) && is.null(tab_dsn)) {
     if (gui) {
       tabresp <- select.list(selectlst, title=caption, multiple=FALSE)
       if (tabresp=="") {
@@ -238,12 +256,19 @@ pcheck.table <- function(tab=NULL, tab_dsn=NULL, tabnm=NULL, tabqry=NULL,
     }
     if (is.null(tabx) && stopifnull) {
       stop(paste(tabnm, "is NULL"))
-      return(NULL)
     }
   }
 
   if (!is.null(tab)) {
     if (is.character(tab)) {
+      if (length(tab) > 1) {
+        if (stopifinvalid) {
+          stop("x has length > 1")
+        } else {
+          return(NULL)
+        }
+      }
+        
       if (obj && exists(tab, envir=.GlobalEnv) && is.data.frame(get(tab))) {
         #message(tab, " exists in Global Environment")
         return(get(tab))
@@ -694,7 +719,6 @@ pcheck.output <- function(out_fmt="csv", out_dsn=NULL, outfolder=NULL,
   ## Check file name
   ###########################################################
   chkfn <- checkfilenm(out_dsn, outfolder=outfolder)
-
   if (is.null(chkfn)) {
     ext <- "db"
     if (is.null(out_dsn)) {
@@ -719,12 +743,11 @@ pcheck.output <- function(out_fmt="csv", out_dsn=NULL, outfolder=NULL,
   } else {
     ext <- getext(chkfn)
   }
-
+ 
   if (is.null(chkfn) || overwrite_dsn || !overwrite_dsn) {
     out_dsn <- getoutfn(out_dsn, outfn.pre=outfn.pre, outfolder=outfolder,
 		outfn.date=outfn.date, overwrite=overwrite_dsn, outfn.default="data",
 		ext=ext, add=add_layer, append=append_layer)
-
     if (any(out_fmt %in% c("sqlite", "gpkg")) && createSQLite) {
       gpkg <- ifelse(out_fmt == "gpkg", TRUE, FALSE)
       out_dsn <- DBcreateSQLite(out_dsn, gpkg=gpkg)
